@@ -18,10 +18,9 @@ class FancyViewer:
 
     def play(self, delay=0.5, keep_history=False):
         for state_index in range(len(self.board_states)):
+            self.clear()
             self.view(state_index)
             time.sleep(delay)
-            if not keep_history:
-                self.clear()
 
         self.view(-1)
 
@@ -33,8 +32,8 @@ class FancyViewer:
         while state_index < len(self.board_states) or not poison_pill.is_set():
             while len(self.board_states) <= state_index or datetime.datetime.now().timestamp() - last_time < delay:
                 time.sleep(0.1)
-            if not keep_history and state_index > 0:
-                self.clear()
+
+            self.clear()
             self.view(state_index)
             last_time = datetime.datetime.now().timestamp()
             state_index += 1
